@@ -12,13 +12,13 @@ our @EXPORT_OK = qw( randomizer );
 sub randomizer {
     my $args = shift;
     my $total;
-    $total += $_ for keys %$args;
+    $total += $_ for values %$args;
     my $weight;
     my $count = 0;
-    for my $set( keys %$args ) {
-        my $result = $args->{$set};
+    for my $key( keys %$args ) {
+        my $set = $args->{$key};
         for ( 1 .. $set ) {
-            $weight->{$count++} = $result;
+            $weight->{$count++} = $key;
         }
     }
     return sub {
@@ -42,7 +42,7 @@ Data::Random::Weighted - get weighted random data
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 Data::Random::Weighted
 
@@ -51,8 +51,8 @@ Used to return random results from a weighted set.
 =head1 Usage
 
 my $rand = randomizer({
-    5 => 'Result',
-    1 => 42,
+    'Result' => 5,
+    42       => 1,
 });
 
 print &$rand;
